@@ -3,6 +3,12 @@ import gc
 import unittest
 import weakref
 
+import os
+import sys
+
+if 'TOX_ENV' not in os.environ:
+    sys.path.insert(0, '../')
+
 from fibers import Fiber, current
 
 
