@@ -1,6 +1,12 @@
 
 import unittest
 
+import os
+import sys
+
+if 'TOX_ENV' not in os.environ:
+    sys.path.insert(0, '../')
+
 import fibers
 from fibers import Fiber
 
